@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_proj.c 10401 2018-01-01 06:02:11Z pwessel $
+ *	$Id: gmt_proj.c 10409 2018-05-31 21:33:08Z pwessel $
  *
  *	Copyright (c) 1991-2018 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -46,7 +46,7 @@
  *	Oblique Mercator
  *	TM Transverse Mercator (Ellipsoidal and Spherical)
  *	UTM Universal Transverse Mercator
- *	Cylindrical Equal-area (e.g., Gall-Peters, Behrmann)
+ *	Cylindrical Equal-area (e.g., Gall, Behrmann)
  *	Cylindrical Equidistant (e.g., Plate Carree)
  *  Conic:
  *	Albers Equal-Area Conic
