@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtconvert.c 10401 2018-01-01 06:02:11Z pwessel $
+ *	$Id: gmtconvert.c 10406 2018-01-02 03:00:27Z pwessel $
  *
  *	Copyright (c) 1991-2018 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -283,7 +283,7 @@ int main (int argc, char **argv)
 		for (k = j = 0; k < n_files; k++) {	/* Get first record from each file */
 			n_expected_fields[k] = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS; /* GMT_MAX_COLUMNS -> Ascii table, must first find the number of fields */
 			n_fields[k] = GMT_input (fp[k], &n_expected_fields[k], &in);
-			if (! GMT_io.status & GMT_IO_SEGMENT_HEADER) {	/* Good, a data record, update number of cols etc */
+			if (! (GMT_io.status & GMT_IO_SEGMENT_HEADER)) {	/* Good, a data record, update number of cols etc */
 				all_set = 1;
 				n_tot_cols += n_expected_fields[k];
 				if (n_tot_cols > n_alloc) {
